/*
 *  
 *  $Id: abrir.h 4387 2011-11-08 08:49:01Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <main/controllers/pacscontroller.h>
#include <string>
#include <list>


namespace GNC {
	namespace GUI {
		class PanelHistorial2;
		class Abrir
		{

		public:
			Abrir();
			~Abrir();

			static void AbrirFichero(wxWindow* pParent, const std::list<std::string>* directLoads = NULL);
			static void AbrirDirectorio(wxWindow* pParent);

		protected:
		};
	}
}
